@@ -8,8 +8,8 @@ use {
 };
 
 custom_error! {pub ProgramError
-    Io {source: io::Error} = "IO Error : {:?}",
-    Termimad {source: termimad::Error} = "Termimad Error : {:?}",
+    Io {source: io::Error} = "IO Error : {}",
+    Termimad {source: termimad::Error} = "Termimad Error : {}",
     Conf {source: ConfError} = "Bad configuration: {}",
     ConfFile {path:String, details: ConfError} = "Bad configuration file {:?} : {}",
     ArgParse {bad: String, valid: String} = "{:?} can't be parsed (valid values: {:?})",
@@ -20,7 +20,6 @@ custom_error! {pub ProgramError
     LaunchError {program: String, source: io::Error} = "Unable to launch {program}: {source}",
     UnknowShell {shell: String} = "Unknown shell: {shell}",
     InternalError {details: String} = "Internal error: {details}", // should not happen
-    TerminalTooSmallError = "Terminal too small", // unable to open panel or app
     InvalidGlobError {pattern: String} = "Invalid glob: {pattern}",
     Unrecognized {token: String} = "Unrecognized: {token}",
     NetError {source: NetError} = "{}",
@@ -30,6 +29,7 @@ custom_error! {pub ProgramError
     UnmappableFile = "File can't be mapped",
     UnprintableFile = "File can't be printed", // has characters that can't be printed without escaping
     SyntectCrashed { details: String } = "Syntect crashed on {details:?}",
+    OpenError { source: opener::OpenError } = "Open error: {}",
 }
 
 custom_error! {pub TreeBuildError
@@ -49,6 +49,7 @@ custom_error! {pub ConfError
     UnknownInternal {verb: String}                  = "not a known internal: {}",
     InvalidSearchMode {details: String}             = "invalid search mode: {}",
     InvalidKey {raw: String}                        = "not a valid key: {}",
+    ParseKey {source: crokey::ParseKeyError}        = "{}",
     ReservedKey {key: String}                       = "reserved key: {}",
     UnexpectedInternalArg {invocation: String}      = "unexpected argument for internal: {}",
     InvalidCols {details: String}                   = "invalid cols definition: {}",
